*
* DO NOT CHANGE THIS MAKEFILE DIRECTLY
*
* THERE ARE NO CONFIGURATION PARAMETERS IN THIS FILE
*

#include "config.h"
#undef global
#undef SHELL

#ifndef COMPILER_FLAGS
#define COMPILER_FLAGS
#endif

#ifndef EXTRA_LIB
#define EXTRA_LIB
#endif

#ifdef HAVE_ROUTING
#define NNMAIL
#else
#define	NNMAIL nnmail
#endif

------------------ MAKE WILL CUT HERE -------------
*
* Notice:  ymakefile is made from xmakefile by the Makefile.
*

CC =	 COMPILER
CPP =	 PREPROC
CFLAGS = COMPILER_FLAGS CDEBUG

*
* Resulting programs
*

BIN_PROG =	nn NNMAIL nntidy nngrep nnquery nnusage nngoback
BIN_LINK =	nncheck nnadmin
LIB_PROG =	aux date_regexp log_entry back_act
MASTER_PROG =	nnmaster

*
* Compilation
*

SHELL = /bin/sh

MASTER = master.o collect.o expire.o update.o \
	global.o options.o active.o db.o nntp.o \
	pack_date.o pack_name.o pack_subject.o news.o digest.o match.o 

NN = 	nn.o admin.o update.o \
	global.o options.o active.o db.o nntp.o \
	init.o variable.o term.o keymap.o macro.o regexp.o \
	menu.o more.o rc.o group.o folder.o \
	articles.o sequence.o selection.o kill.o \
	answer.o reroute.o save.o unshar.o decode.o execute.o \
	pack_date.o pack_name.o pack_subject.o news.o digest.o match.o 

MAIL = nnmail.o reroute.o global.o options.o update.o


all:	$(BIN_PROG) $(LIB_PROG) $(MASTER_PROG)

client: update.o $(BIN_PROG) $(LIB_PROG)


nn:	$(NN) 
	$(CC) $(CFLAGS) $(NN) TERMLIB EXTRA_LIB -o nn

nnmaster: $(MASTER)
	$(CC) $(CFLAGS) $(MASTER) EXTRA_LIB -o nnmaster

nnmail:	$(MAIL)
	$(CC) $(CFLAGS) $(MAIL) EXTRA_LIB -o nnmail

nntidy:	nntidy.sh prefix
	cat prefix nntidy.sh > nntidy
	chmod +x nntidy

nngrep:	nngrep.sh prefix
	cat prefix nngrep.sh > nngrep
	chmod +x nngrep

nngoback: nngoback.sh prefix
	cat prefix nngoback.sh > nngoback
	chmod +x nngoback

nnquery: nnquery.sh prefix
	cat prefix nnquery.sh > nnquery
	chmod +x nnquery

nnusage: nnusage.sh prefix
	cat prefix nnusage.sh > nnusage
	chmod +x nnusage

* LIB PROGRAMS

date_regexp: date_regexp.o
	$(CC) $(CFLAGS) date_regexp.o EXTRA_LIB -o date_regexp

log_entry: log_entry.o global.o update.o
	$(CC) $(CFLAGS) log_entry.o global.o update.o EXTRA_LIB -o log_entry

aux:	 aux.sh prefix
	cat prefix aux.sh > aux
	chmod +x aux

back_act: back_act.sh prefix
	cat prefix back_act.sh > back_act
	chmod +x back_act


*
* Clean -- remove compiled programs
*

clean:
	rm -f $(BIN_PROG) $(LIB_PROG) $(MASTER_PROG) cvt-help

*
* Compilation counter updating
*

update.o:	update.h update.c patchlevel.h
	-$(CC) -c $(CFLAGS) update.c

*
* Installation
*

install: prefix install.bin install.lib install.master install.man
	@sh install_aux incr OWNER GROUP LIB_DIRECTORY "Log" 666 \
		"Installation" DB_DIRECTORY

install.client: prefix install.bin install.lib install.man
	@sh install_aux incr OWNER GROUP LIB_DIRECTORY "Log" 666 \
		"Client Installation"

install.bin: $(BIN_PROG)
	@sh install_aux bin OWNER GROUP BIN_DIRECTORY "$(BIN_PROG)" 755 \
		"$(BIN_LINK)"

install.lib: $(LIB_PROG) cvt-help
	@sh install_aux aux  OWNER GROUP LIB_DIRECTORY "$(LIB_PROG)" 755
	@sh install_aux help OWNER GROUP LIB_DIRECTORY "help.*" 644

install.master: $(MASTER_PROG)
	@sh install_aux master OWNER GROUP LIB_DIRECTORY "$(MASTER_PROG)" 6755

install.man: 
	@sh install_aux 1  OWNER GROUP USER_MAN_DIR USER_MAN_SECTION 644
	@sh install_aux 1m OWNER GROUP SYS_MAN_DIR  SYS_MAN_SECTION  644

online.manual:
	@sh install_aux online OWNER GROUP LIB_DIRECTORY "n*.1 n*.1m" 444

*
* initialize database
*

initdb:
	@sh install_aux db OWNER GROUP DB_DIRECTORY ". DATA" 755
	@sh install_aux init . . LIB_DIRECTORY "$(MASTER_PROG)" . "-I"


*
* dependencies
*

prefix:	prefix.sh config.h update.h patchlevel.h ymakefile
	cp prefix.sh prefix.c
	$(CPP) prefix.c | \
	sed -e '1,/CUT PREFIX HERE/d' \
	    -e '/prefix.c/d' \
	    -e '/^[ 	]*$$/d' \
	    -e 's/^&/#/' \
	    -e 's/[ 	]*=[ 	]*/=/' > prefix
	rm -f prefix.c

cvt-help:	cvt-help.c
	$(CC) -o cvt-help cvt-help.c

active.o:	active.c config.h global.h vararg.h data.h
admin.o:	admin.c config.h global.h vararg.h data.h db.h term.h
answer.o:	answer.c config.h global.h vararg.h data.h news.h term.h \
		keymap.h
articles.o:	articles.c config.h global.h vararg.h data.h db.h articles.h \
		match.h
collect.o:	collect.c config.h global.h vararg.h data.h db.h news.h
cvt-help.o:	cvt-help.c
date_regexp.o:	date_regexp.c config.h global.h vararg.h data.h
db.o:		db.c config.h global.h vararg.h data.h db.h
decode.o:	decode.c config.h global.h vararg.h data.h
digest.o:	digest.c config.h global.h vararg.h data.h news.h match.h  \
		debug.h
execute.o:	execute.c config.h global.h vararg.h data.h term.h
expire.o:	expire.c config.h global.h vararg.h data.h db.h
folder.o:	folder.c config.h global.h vararg.h data.h articles.h news.h \
		term.h menu.h
global.o:	global.c config.h global.h vararg.h data.h
group.o:	group.c config.h global.h vararg.h data.h articles.h db.h \
		term.h menu.h keymap.h regexp.h
init.o:		init.c config.h global.h vararg.h data.h articles.h term.h \
		keymap.h menu.h
keymap.o:	keymap.c config.h global.h vararg.h data.h keymap.h term.h
kill.o:		kill.c config.h global.h vararg.h data.h term.h regexp.h
log_entry.o:	log_entry.c
macro.o:	macro.c config.h global.h vararg.h data.h keymap.h term.h
master.o:	master.c config.h global.h vararg.h data.h db.h options.h
match.o:	match.c
menu.o:		menu.c config.h global.h vararg.h data.h articles.h term.h \
		keymap.h menu.h regexp.h
more.o:		more.c config.h global.h vararg.h data.h news.h term.h \
		menu.h keymap.h regexp.h
news.o:		news.c config.h global.h vararg.h data.h news.h
nn.o:		nn.c config.h global.h vararg.h data.h menu.h term.h \
		keymap.h options.h
nnmail.o:	nnmail.c config.h global.h vararg.h data.h options.h
nntp.o:		nntp.c config.h global.h vararg.h data.h nntp.h
options.o:	options.c config.h global.h vararg.h data.h options.h
pack_date.o:	pack_date.c config.h global.h vararg.h data.h
pack_name.o:	pack_name.c config.h global.h vararg.h data.h
pack_subject.o:	pack_subject.c config.h global.h vararg.h data.h
rc.o:		rc.c config.h global.h vararg.h data.h term.h debug.h
regexp.o:	regexp.c config.h global.h vararg.h data.h regexp.h
reroute.o:	reroute.c config.h global.h vararg.h data.h
save.o:		save.c config.h global.h vararg.h data.h term.h keymap.h \
		news.h
selection.o:	selection.c config.h global.h vararg.h data.h term.h\
		 articles.h
sequence.o:	sequence.c config.h global.h vararg.h data.h debug.h
term.o:		term.c config.h global.h vararg.h data.h term.h keymap.h
unshar.o:	unshar.c config.h global.h vararg.h data.h
update.o:	update.c patchlevel.h update.h
variable.o:	variable.c config.h global.h vararg.h data.h

* link debugging version

nn1:	$(NN) 
	$(CC) $(CFLAGS) $(NN) TERMLIB EXTRA_LIB -Mnn1 -o nn1

* this is probably non-portable so it is ifdef-ed

#ifdef WITH_LINT
lint:
	echo LINTING NN
	lint $(NN:.o=.c)
	echo LINTING MASTER
	lint $(MASTER:.o=.c)
#endif
